@@ -36,23 +36,43 @@ def main():
 		print('')
 		print('bool WithTruncate = [True,False]')
 
+
 class dbimport():
 	def __init__(self,csv_filename,tablename='',WithTruncate=False):
+
 		tbl = tablename
 		dber = schemawiz()
 		if ((tablename != '') and (dber.dbthings.postgres_db.does_table_exist(tablename))):
 			dber.justload_postgres_from_csv(csv_filename,tablename,WithTruncate)
 		else:
-			tbl = dber.createload_postgres_from_csv(csv_filename,tablename)
+			output_ddl_filename = self.getoutputfilename(csv_filename,'z.' + tablename) + '.ddl'
+			tbl = dber.createload_postgres_from_csv(csv_filename,tablename,output_ddl_filename)
 
 		print(dber.dbthings.postgres_db.queryone('SELECT COUNT(*) FROM ' + tbl))
-		dber.dbthings.postgres_db.close()
+		#dber.dbthings.postgres_db.close()
 
 		print('postgres_import Done')
 
+	def getoutputfilename(self,csv_filename,ddl_output_filename):
+		# zetl_scripts/someetl/thisfile.csv
+		filedelimiter = '\\'
+		if csv_filename.find('/') > -1:
+			filedelimiter = '/'
+
+		newfile = ''
+		partlist = csv_filename.split(filedelimiter)
+		if partlist[0] != csv_filename:
+			for i in range(0,len(partlist)-1):
+				newfile += partlist[i] + filedelimiter
+
+		newfile += ddl_output_filename
+
+		return newfile
 
 if __name__ == '__main__':
-	#myexp = dbimport('CanadianPostalCodes.csv','canweather.canadianpostalcodes',True)
+	#myexp = dbimport('sample.csv','canweather.sample6',True)
+	#print(getoutputfilename('zetl_scripts/someetl/thisfile.csv','z.canweather.canadianpostalcodes.dll'))
+
 	main()
 
 		
\ No newline at end of file
